package es.verdnatura.presentation.view.feature.historicoshelvinglog.model


class ShelvingLog(
    var id: String = "",
    var originFk: String = "",
    var name: String = "",
    var creationDate: String = "",
    var description: String = "",
    var isError: Boolean = false,
    var errorMessage: String = ""
)


class ShelvingLogList(
    var list: List<ShelvingLog> = listOf()
)

class ShelvingLogSalixList(
    var list: List<ShelvingLogSalix> = listOf()
)
class ShelvingLogSalix(
    var id: Int?=null,
    var code: String?=null,
    var parkingFk: Int?=null,
    var isPrinted: Boolean?=null,
    var priority: Int?=null,
    var userFk: Int?=null,
    var isRecyclable: Boolean?=null,
    var isError:Boolean?=null,
    var errorMessage: String?=null
)